@@ -1,10 +1,10 @@
-/* $Id: VBoxPci.c 103540 2015-10-20 13:58:41Z bird $ */
+/* $Id: VBoxPci.c 118839 2017-10-28 15:14:05Z bird $ */
 /** @file
  * VBoxPci - PCI card passthrough support (Host), Common Code.
  */
 
 /*
- * Copyright (C) 2011-2015 Oracle Corporation
+ * Copyright (C) 2011-2017 Oracle Corporation
  *
  * This file is part of VirtualBox Open Source Edition (OSE), as
  * available from http://www.virtualbox.org. This file is free software;
@@ -13,6 +13,15 @@
  * Foundation, in version 2 as it comes in the "COPYING" file of the
  * VirtualBox OSE distribution. VirtualBox OSE is distributed in the
  * hope that it will be useful, but WITHOUT ANY WARRANTY of any kind.
+ *
+ * The contents of this file may alternatively be used under the terms
+ * of the Common Development and Distribution License Version 1.0
+ * (CDDL) only, as it comes in the "COPYING.CDDL" file of the
+ * VirtualBox OSE distribution, in which case the provisions of the
+ * CDDL are applicable instead of those of the GPL.
+ *
+ * You may elect to license modified versions of this file under the
+ * terms and conditions of either the GPL or the CDDL or both.
  */
 
 /** @page pg_rawpci     VBoxPci - host PCI support
@@ -277,14 +286,14 @@ static DECLCALLBACK(int) vboxPciDevMapRegion(PRAWPCIDEVPORT pPort,
                                              RTHCPHYS       RegionStart,
                                              uint64_t       u64RegionSize,
                                              int32_t        fFlags,
-                                             RTR0PTR        *pRegionBase)
+                                             RTR0PTR        *pRegionBaseR0)
 {
     PVBOXRAWPCIINS pThis = DEVPORT_2_VBOXRAWPCIINS(pPort);
     int            rc;
 
     vboxPciDevLock(pThis);
 
-    rc = vboxPciOsDevMapRegion(pThis, iRegion, RegionStart, u64RegionSize, fFlags, pRegionBase);
+    rc = vboxPciOsDevMapRegion(pThis, iRegion, RegionStart, u64RegionSize, fFlags, pRegionBaseR0);
 
     vboxPciDevUnlock(pThis);
 
@@ -443,8 +452,11 @@ static DECLCALLBACK(int) vboxPciDevPowerStateChange(PRAWPCIDEVPORT    pPort,
  *
  * @returns VBox status code.
  * @param   pGlobals            The globals.
- * @param   pszName             The instance name.
+ * @param   u32HostAddress      Host address.
+ * @param   fFlags              Flags.
+ * @param   pVmCtx              VM context.
  * @param   ppDevPort           Where to store the pointer to our port interface.
+ * @param   pfDevFlags          The device flags.
  */
 static int vboxPciNewInstance(PVBOXRAWPCIGLOBALS pGlobals,
                               uint32_t           u32HostAddress,
@@ -599,11 +611,11 @@ static DECLCALLBACK(int)  vboxPciFactoryInitVm(PRAWPCIFACTORY       pFactory,
  */
 static DECLCALLBACK(void)  vboxPciFactoryDeinitVm(PRAWPCIFACTORY       pFactory,
                                                   PVM                  pVM,
-                                                  PRAWPCIPERVM         pPciData)
+                                                  PRAWPCIPERVM         pVmData)
 {
-    if (pPciData->pDriverData)
+    if (pVmData->pDriverData)
     {
-        PVBOXRAWPCIDRVVM pThis = (PVBOXRAWPCIDRVVM)pPciData->pDriverData;
+        PVBOXRAWPCIDRVVM pThis = (PVBOXRAWPCIDRVVM)pVmData->pDriverData;
 
 #ifdef VBOX_WITH_IOMMU
         /* If we have IOMMU, need to unmap all guest's physical pages from IOMMU on VM termination. */
@@ -618,7 +630,7 @@ static DECLCALLBACK(void)  vboxPciFactoryDeinitVm(PRAWPCIFACTORY       pFactory,
         }
 
         RTMemFree(pThis);
-        pPciData->pDriverData = NULL;
+        pVmData->pDriverData = NULL;
     }
 }
 
